.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.systemaccountmodel
-------------------------------

.. automodule:: reahl.systemaccountmodel



AccountManagementInterface
""""""""""""""""""""""""""

.. autoclass:: AccountManagementInterface
   :members:


UserSession
"""""""""""

.. autoclass:: UserSession
   :members:

SystemAccount
"""""""""""""

.. autoclass:: SystemAccount
   :members:

EmailAndPasswordSystemAccount
"""""""""""""""""""""""""""""

.. autoclass:: EmailAndPasswordSystemAccount
   :members:


PasswordException
"""""""""""""""""

.. autoexception:: PasswordException
   :members:
   
InvalidPasswordException
""""""""""""""""""""""""

.. autoexception:: InvalidPasswordException
   :members:
   
KeyException
""""""""""""

.. autoexception:: KeyException
   :members:

InvalidEmailException
"""""""""""""""""""""

.. autoexception:: InvalidEmailException
   :members:

NoSuchAccountException
""""""""""""""""""""""

.. autoexception:: NoSuchAccountException
   :members:

NotUniqueException
""""""""""""""""""

.. autoexception:: NotUniqueException
   :members:

AccountNotActiveException
"""""""""""""""""""""""""

.. autoexception:: AccountNotActiveException
   :members:



